@@ -48,6 +48,8 @@ DLL_EXPORT const char *kto_check_retval2txt(int retval)
 DLL_EXPORT const char *kto_check_retval2iso(int retval)
 {
    switch(retval){
+      case INVALID_REGULAR_EXPRESSION_CNT: return "Ungltiger Zhler in regulrem Ausdruck (innerhalb von {})";
+      case INVALID_REGULAR_EXPRESSION: return "Ungltiger regulrer Ausdruck (enthlt zwei Zeichen aus [+?*] nacheinander)";
       case INVALID_HANDLE: return "Ungltiges Handle angegeben";
       case INVALID_BIQ_INDEX: return "Ungltiger Index fr die biq_*() Funktionen";
       case ARRAY_INDEX_OUT_OF_RANGE: return "Der Array-Index liegt auerhalb des gltigen Bereichs";
@@ -216,6 +218,8 @@ DLL_EXPORT const char *kto_check_retval2iso(int retval)
 DLL_EXPORT const char *kto_check_retval2dos(int retval)
 {
    switch(retval){
+      case INVALID_REGULAR_EXPRESSION_CNT: return "Ungltiger Z hler in regul rem Ausdruck (innerhalb von {})";
+      case INVALID_REGULAR_EXPRESSION: return "Ungltiger regul rer Ausdruck (enth lt zwei Zeichen aus [+?*] nacheinander)";
       case INVALID_HANDLE: return "Ungltiges Handle angegeben";
       case INVALID_BIQ_INDEX: return "Ungltiger Index fr die biq_*() Funktionen";
       case ARRAY_INDEX_OUT_OF_RANGE: return "Der Array-Index liegt auerhalb des gltigen Bereichs";
@@ -384,6 +388,8 @@ DLL_EXPORT const char *kto_check_retval2dos(int retval)
 DLL_EXPORT const char *kto_check_retval2html(int retval)
 {
    switch(retval){
+      case INVALID_REGULAR_EXPRESSION_CNT: return "Ung&uuml;ltiger Z&auml;hler in regul&auml;rem Ausdruck (innerhalb von {})";
+      case INVALID_REGULAR_EXPRESSION: return "Ung&uuml;ltiger regul&auml;rer Ausdruck (enth&auml;lt zwei Zeichen aus [+?*] nacheinander)";
       case INVALID_HANDLE: return "Ung&uuml;ltiges Handle angegeben";
       case INVALID_BIQ_INDEX: return "Ung&uuml;ltiger Index f&uuml;r die biq_*() Funktionen";
       case ARRAY_INDEX_OUT_OF_RANGE: return "Der Array-Index liegt au&szlig;erhalb des g&uuml;ltigen Bereichs";
@@ -552,6 +558,8 @@ DLL_EXPORT const char *kto_check_retval2html(int retval)
 DLL_EXPORT const char *kto_check_retval2utf8(int retval)
 {
    switch(retval){
+      case INVALID_REGULAR_EXPRESSION_CNT: return "Ungültiger Zähler in regulärem Ausdruck (innerhalb von {})";
+      case INVALID_REGULAR_EXPRESSION: return "Ungültiger regulärer Ausdruck (enthält zwei Zeichen aus [+?*] nacheinander)";
       case INVALID_HANDLE: return "Ungültiges Handle angegeben";
       case INVALID_BIQ_INDEX: return "Ungültiger Index für die biq_*() Funktionen";
       case ARRAY_INDEX_OUT_OF_RANGE: return "Der Array-Index liegt außerhalb des gültigen Bereichs";
@@ -720,6 +728,8 @@ DLL_EXPORT const char *kto_check_retval2utf8(int retval)
 DLL_EXPORT const char *kto_check_retval2txt_short(int retval)
 {
    switch(retval){
+      case INVALID_REGULAR_EXPRESSION_CNT: return "INVALID_REGULAR_EXPRESSION_CNT";
+      case INVALID_REGULAR_EXPRESSION: return "INVALID_REGULAR_EXPRESSION";
       case INVALID_HANDLE: return "INVALID_HANDLE";
       case INVALID_BIQ_INDEX: return "INVALID_BIQ_INDEX";
       case ARRAY_INDEX_OUT_OF_RANGE: return "ARRAY_INDEX_OUT_OF_RANGE";
